@@ -395,6 +395,7 @@ class TestClient(base.IronicLibTestCase):
         }
         cctx = self.client.prepare('foo.2001:db8::1')
         self.assertEqual('2001:db8::1', cctx.host)
+        self.assertEqual(8089, cctx.port)
         result = cctx.call(self.context, 'do_something', answer=42)
         self.assertEqual(42, result)
         mock_session.return_value.post.assert_called_once_with(
@@ -404,18 +405,35 @@ class TestClient(base.IronicLibTestCase):
                   'params': {'answer': 42, 'context': self.ctx_json},
                   'id': self.context.request_id})
 
+    def test_call_ipv6_success_rfc2732(self, mock_session):
+        response = mock_session.return_value.post.return_value
+        response.json.return_value = {
+            'jsonrpc': '2.0',
+            'result': 42
+        }
+        cctx = self.client.prepare('foo.[2001:db8::1]:8192')
+        self.assertEqual('2001:db8::1', cctx.host)
+        result = cctx.call(self.context, 'do_something', answer=42)
+        self.assertEqual(42, result)
+        mock_session.return_value.post.assert_called_once_with(
+            'http://[2001:db8::1]:8192',
+            json={'jsonrpc': '2.0',
+                  'method': 'do_something',
+                  'params': {'answer': 42, 'context': self.ctx_json},
+                  'id': self.context.request_id})
+
     def test_call_success_with_version(self, mock_session):
         response = mock_session.return_value.post.return_value
         response.json.return_value = {
             'jsonrpc': '2.0',
             'result': 42
         }
-        cctx = self.client.prepare('foo.example.com', version='1.42')
+        cctx = self.client.prepare('foo.example.com:8192', version='1.42')
         self.assertEqual('example.com', cctx.host)
         result = cctx.call(self.context, 'do_something', answer=42)
         self.assertEqual(42, result)
         mock_session.return_value.post.assert_called_once_with(
-            'http://example.com:8089',
+            'http://example.com:8192',
             json={'jsonrpc': '2.0',
                   'method': 'do_something',
                   'params': {'answer': 42, 'context': self.ctx_json,
@@ -620,10 +638,10 @@ class TestClient(base.IronicLibTestCase):
                   'method': 'do_something',
                   'params': {'node': request, 'context': self.ctx_json}})
         self.assertEqual(2, mock_log.call_count)
-        node = mock_log.call_args_list[0][0][2]['params']['node']
+        node = mock_log.call_args_list[0][0][3]['params']['node']
         self.assertEqual(node, {'redfish_username': 'admin',
                                 'redfish_password': '***'})
-        resp_text = mock_log.call_args_list[1][0][2]
+        resp_text = mock_log.call_args_list[1][0][3]
         self.assertEqual(body.replace('passw0rd', '***'), resp_text)
 
 
